ProvideErrorKind

Trait ProvideErrorKind 

pub trait ProvideErrorKind {
    // Required methods
    fn retryable_error_kind(&self) -> Option<ErrorKind>;
    fn code(&self) -> Option<&str>;
}
Trait that provides an ErrorKind and an error code.

Required Methods

fn retryable_error_kind(&self) -> Option<ErrorKind>

Returns the ErrorKind when the error is modeled as retryable

If the error kind cannot be determined (e.g. the error is unmodeled at the error kind depends on an HTTP status code, return None.

fn code(&self) -> Option<&str>

Returns the code for this error if one exists

Implementations on Foreign Types

Source

impl ProvideErrorKind for CreateOAuth2TokenError

Source

impl ProvideErrorKind for DeleteConsoleAuthorizationConfigurationError

Source

impl ProvideErrorKind for DeleteResourcePermissionStatementError

Source

impl ProvideErrorKind for GetConsoleAuthorizationConfigurationError

Source

impl ProvideErrorKind for GetResourcePolicyError

Source

impl ProvideErrorKind for ListResourcePermissionStatementsError

Source

impl ProvideErrorKind for PutConsoleAuthorizationConfigurationError

Source

impl ProvideErrorKind for PutResourcePermissionStatementError

Source

impl ProvideErrorKind for GetRoleCredentialsError

Source

impl ProvideErrorKind for ListAccountRolesError

Source

impl ProvideErrorKind for ListAccountsError

Source

impl ProvideErrorKind for LogoutError

Source

impl ProvideErrorKind for AssumeRoleError

Source

impl ProvideErrorKind for AssumeRoleWithSAMLError

Source

impl ProvideErrorKind for AssumeRoleWithWebIdentityError

Source

impl ProvideErrorKind for AssumeRootError

Source

impl ProvideErrorKind for DecodeAuthorizationMessageError

Source

impl ProvideErrorKind for GetAccessKeyInfoError

Source

impl ProvideErrorKind for GetCallerIdentityError

Source

impl ProvideErrorKind for GetDelegatedAccessTokenError

Source

impl ProvideErrorKind for GetFederationTokenError

Source

impl ProvideErrorKind for GetSessionTokenError

Source

impl ProvideErrorKind for GetWebIdentityTokenError



impl ProvideErrorKind for CreateTokenError



impl ProvideErrorKind for CreateTokenWithIAMError



impl ProvideErrorKind for RegisterClientError



impl ProvideErrorKind for StartDeviceAuthorizationError

Implementors